/* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 8; tab-width: 8 -*- */

/* nautilus-canvas-view.h - interface for canvas view of directory.
 *
 * Copyright (C) 2000 Eazel, Inc.
 *
 * The Gnome Library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * The Gnome Library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with the Gnome Library; see the file COPYING.LIB.  If not,
 * see <http://www.gnu.org/licenses/>.
 *
 * Authors: John Sullivan <sullivan@eazel.com>
 *
 */

#ifndef NAUTILUS_CANVAS_VIEW_H
#define NAUTILUS_CANVAS_VIEW_H

#include "nautilus-files-view.h"
#include "nautilus-canvas-container.h"

G_BEGIN_DECLS

#define NAUTILUS_TYPE_CANVAS_VIEW nautilus_canvas_view_get_type()

G_DECLARE_DERIVABLE_TYPE (NautilusCanvasView, nautilus_canvas_view, NAUTILUS, CANVAS_VIEW, NautilusFilesView)

struct _NautilusCanvasViewClass {
	NautilusFilesViewClass parent_class;

        NautilusCanvasContainer * (* create_canvas_container) (NautilusCanvasView *canvas_view);
};

int     nautilus_canvas_view_compare_files (NautilusCanvasView   *canvas_view,
					  NautilusFile *a,
					  NautilusFile *b);
void    nautilus_canvas_view_filter_by_screen (NautilusCanvasView *canvas_view,
					     gboolean filter);
void    nautilus_canvas_view_clean_up_by_name (NautilusCanvasView *canvas_view);

NautilusFilesView * nautilus_canvas_view_new (NautilusWindowSlot *slot);

NautilusCanvasContainer * nautilus_canvas_view_get_canvas_container (NautilusCanvasView *view);

void
nautilus_canvas_view_set_directory_keep_aligned (NautilusCanvasView *canvas_view,
                                                 NautilusFile       *file,
                                                 gboolean            keep_aligned);


typedef gboolean (*SortCriterionMatchFunc) (NautilusFile *file);

typedef struct
{
    const NautilusFileSortType sort_type;
    const char *metadata_text;
    const char *action_target_name;
    const gboolean reverse_order;
    SortCriterionMatchFunc match_func;
} SortCriterion;

const SortCriterion * get_sort_criterion_by_action_target_name (const char *action_target_name);

void            switch_to_manual_layout (NautilusCanvasView *view);

void            update_sort_criterion (NautilusCanvasView  *canvas_view,
                                       const SortCriterion *sort,
                                       gboolean             set_metadata);
NautilusCanvasContainer * get_canvas_container (NautilusCanvasView *canvas_view);

void            nautilus_canvas_view_reveal_selection (NautilusFilesView *view);

G_END_DECLS

#endif /* NAUTILUS_CANVAS_VIEW_H */
